@@ -1,6 +1,6 @@
 
 /*
- *             Automatically Tuned Linear Algebra Software v3.5.0
+ *             Automatically Tuned Linear Algebra Software v3.5.6
  *                    (C) Copyright 2001 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -30,11 +30,18 @@
  */
 #include <stdio.h>
 #include <stdlib.h>
+#ifdef ATL_AVgcc
+   #include <altivec.h>
+#endif
 main(int nargs, char **args)
 {
    char ln[128];
    float *tp;
+#ifdef ATL_AVgcc
+   vector float v0, v1 = (vector float) {2.0f, 3.0f, 4.0f, 5.0f};
+#else
    vector float v0, v1 = (vector float) (2.0f, 3.0f, 4.0f, 5.0f);
+#endif
 
    tp = (void*) (16+ ((((size_t)ln)>>4)<<4));
    tp[0] = 0.0; tp[1] = 1.0; tp[2] = 2.0; tp[3] = 3.0;
