@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.5.0
+ *             Automatically Tuned Linear Algebra Software v3.5.6
  *                    (C) Copyright 2001 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -47,7 +47,7 @@ int f77getri(const enum ATLAS_ORDER Order, const int N, TYPE *A, const int lda,
    int i;
    const int MN=N;
    #ifdef ATL_FunkyInts
-      const F77_INTEGER F77M=M, F77N=N, F77lda=lda;
+      const F77_INTEGER F77N=N, F77lda=lda;
       F77_INTEGER info, *F77ipiv;
       F77_INTEGER F77lwork=(*lwork);
    #else
