@@ -1,6 +1,6 @@
 
 /*
- *             Automatically Tuned Linear Algebra Software v3.5.0
+ *             Automatically Tuned Linear Algebra Software v3.5.6
  *                    (C) Copyright 2001 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -28,6 +28,17 @@
  * POSSIBILITY OF SUCH DAMAGE.
  *
  */
+#ifndef Mjoin
+   #define Mjoin(pre, nam) my_join(pre, nam)
+   #define my_join(pre, nam) pre ## nam
+#endif
+
+#if defined(ATL_OS_WinNT) || defined(ATL_OS_Win9x)
+   #define ATL_AUSERMM Mjoin(_,ATL_USERMM)
+#else
+   #define ATL_AUSERMM ATL_USERMM
+#endif
+
 
 #ifdef ATL_GAS_x8632
    #define movq movl
@@ -102,14 +113,13 @@
 #define prefB(mem) prefetcht0	mem
 #define prefC(mem) prefetcht0	mem
 #   byte:                  28           32           36             40
-# void ATL_USERMM(const int M, const int N, const int K, const TYPE alpha,
+# void ATL_AUSERMM(const int M, const int N, const int K, const TYPE alpha,
 #                 const TYPE *A, const int lda, const TYPE *B, const int ldb,
 #                 const TYPE beta, TYPE *C, const int ldc)
 #
 	.text
-.global ATL_USERMM
-	.type	ATL_USERMM,@function
-ATL_USERMM:
+.global ATL_AUSERMM
+ATL_AUSERMM:
 #ifdef ATL_GAS_x8632
 #
 #	Save callee-saved iregs
