@@ -1,6 +1,6 @@
 
 /*
- *             Automatically Tuned Linear Algebra Software v3.5.0
+ *             Automatically Tuned Linear Algebra Software v3.5.6
  *                    (C) Copyright 2001 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -28,6 +28,20 @@
  * POSSIBILITY OF SUCH DAMAGE.
  *
  */
+#ifndef ATL_GAS_x8664
+   #error "This kernel requires x86-64 assembly!"
+#endif
+#ifndef Mjoin
+   #define Mjoin(pre, nam) my_join(pre, nam)
+   #define my_join(pre, nam) pre ## nam
+#endif
+
+#if defined(ATL_OS_WinNT) || defined(ATL_OS_Win9x)
+   #define ATL_AUSERMM Mjoin(_,ATL_USERMM)
+#else
+   #define ATL_AUSERMM ATL_USERMM
+#endif
+
 
 #if !defined(NB) || (NB == 0)
    #error "NB must be a compile-time constant!"
@@ -98,16 +112,15 @@
 
 #
 # BYTE:                  %rdi         %rsi         %rdx              xmm0
-# void ATL_USERMM(const int M, const int N, const int K, const TYPE alpha,
+# void ATL_AUSERMM(const int M, const int N, const int K, const TYPE alpha,
 # BYTE:                    %rcx            %r8            %r9              8
 #                 const TYPE *A, const int lda, const TYPE *B, const int ldb,
 # BYTE:                     %xmm1       16             24
 #                 const TYPE beta, TYPE *C, const int ldc)
 #
 	.text
-.global ATL_USERMM
-	.type	ATL_USERMM,@function
-ATL_USERMM:
+.global ATL_AUSERMM
+ATL_AUSERMM:
 #
 #	Save callee-saved iregs
 #
