@@ -1,6 +1,6 @@
 
 /*
- *             Automatically Tuned Linear Algebra Software v3.5.0
+ *             Automatically Tuned Linear Algebra Software v3.5.6
  *                    (C) Copyright 2001 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -98,8 +98,12 @@ void ATL_USERMM
                  vC0_2, vC1_2, vC2_2, vC3_2, vC0_3, vC1_3, vC2_3, vC3_3;
    const vector float nzero =  VECTOR_INIT(-0.0f, -0.0f, -0.0f, -0.0f);
    #ifndef ATL_NoIEEE /* turn on java/ieee mode */
-      const vector int izero   =  VECTOR_INITI(0,0,0,0);
-      vec_mtvscr(izero);
+      #ifdef ATL_AVgcc
+         const vector int izero   =  VECTOR_INITI(0,0,0,0);
+         vec_mtvscr(izero);
+      #else
+         vec_mtvscr((vector unsigned long)(0));
+      #endif
    #endif
 
    vC = malloc(ATL_Cachelen + sizeof(float)*16);
