@@ -7,21 +7,14 @@ TYPE ATL_UASUM(const int N, const TYPE *X, const int incX)
    int n;
    register TYPE t0=ATL_rzero, t1=ATL_rzero, t2=ATL_rzero, t3=ATL_rzero;
    const TYPE *stX, *stX0 = X+N;
-   size_t ii;
 
-   n = ATL_MulBySize(4); /* 4 loop unrolling */
-   ii = (size_t) X;
-   ii -= (ii/n)*n;  /* align on loop length */
-   if (ii > ATL_sizeof)  /* not aligned */
+   n = ATL_AlignOffset(N, X, ATL_sizeof, ATL_MulBySize(4));
+   if (n)  /* not aligned */
    {
-      ii = n - ii;
-      n = ATL_DivBySize(ii);
-      n = Mmin(n, N);
       stX = X + n;
       do t0 += myabs(*X); while(++X != stX);
-      n = N - n;
    }
-   else n = N;
+   n = N - n;
 
    stX = X + ((n>>2)<<2);
    if (X != stX)
