@@ -144,6 +144,16 @@ int LineIsCont(char *ln)
    return(iret);
 }
 
+void FixFlags(char *ln)
+{
+   int i, iret=0;
+   for(i=0; ln[i]; i++);
+   if (i)
+   {
+      for(i--; isspace(ln[i]); i--) ln[i] = '\0';
+   }
+}
+
 FILENODE *ReadFile(char pre)
 {
    FILE *fpin;
@@ -168,6 +178,8 @@ FILENODE *ReadFile(char pre)
       {
          assert(fgets(cc, 256, fpin) != NULL);
          assert(fgets(ccflags, 512, fpin) != NULL);
+         FixFlags(cc);
+         FixFlags(ccflags);
          pcc = cc;
          pccflags = ccflags;
       }
@@ -496,9 +508,9 @@ FILENODE *TstFile(char pre, FILENODE *fbase, int *N)
       fn = fp->next;
       i = sprintf(ln, "make %casumtest urout=%s opt=\"", pre, fp->rout);
       if (fp->incX == 0) i += sprintf(ln+i, " -X 4 1 -1 2 -3");
-      i += sprintf(ln+i, "\"");
-      if (fp->cc) i+= sprintf(ln+i, "UCC=\"%s\"", fp->cc);
-      if (fp->ccflags) i+= sprintf(ln+i, "UCCFLAGS=\"%s\"", fp->ccflags);
+      i += sprintf(ln+i, "\" ");
+      if (fp->cc) i += sprintf(ln+i, "UCC=\"%s\" ", fp->cc);
+      if (fp->ccflags) i += sprintf(ln+i, "UCCFLAGS=\"%s\" ", fp->ccflags);
       sprintf(ln+i, "\n");
       fprintf(stderr, "TST: %s", ln);
       #if 1
