@@ -144,6 +144,16 @@ int LineIsCont(char *ln)
    return(iret);
 }
 
+void FixFlags(char *ln)
+{
+   int i, iret=0;
+   for(i=0; ln[i]; i++);
+   if (i)
+   {
+      for(i--; isspace(ln[i]); i--) ln[i] = '\0';
+   }
+}
+
 FILENODE *ReadFile(char pre)
 {
    FILE *fpin;
@@ -174,6 +184,8 @@ FILENODE *ReadFile(char pre)
       {
          assert(fgets(cc, 256, fpin) != NULL);
          assert(fgets(ccflags, 512, fpin) != NULL);
+         FixFlags(cc);
+         FixFlags(ccflags);
          pcc = cc;
          pccflags = ccflags;
       }
@@ -579,9 +591,9 @@ FILENODE *TstFile(char pre, FILENODE *fbase, int *N)
       }
       else if (fp->alpha ==  1) i += sprintf(ln+i, " -a 1 1.0");
       else if (fp->alpha == -1) i += sprintf(ln+i, " -a 1 -1.0");
-      i += sprintf(ln+i, "\"");
-      if (fp->cc) i+= sprintf(ln+i, "UCC=\"%s\"", fp->cc);
-      if (fp->ccflags) i+= sprintf(ln+i, "UCCFLAGS=\"%s\"", fp->ccflags);
+      i += sprintf(ln+i, "\" ");
+      if (fp->cc) i += sprintf(ln+i, "UCC=\"%s\" ", fp->cc);
+      if (fp->ccflags) i += sprintf(ln+i, "UCCFLAGS=\"%s\" ", fp->ccflags);
       sprintf(ln+i, "\n");
       fprintf(stderr, "TST: %s", ln);
       #if 1
@@ -683,7 +695,7 @@ void MangleIncs(FILE *fpout, char *spc, char pre)
    " *%s -  if both abs(inc) are 1, or if neither, make incY positive\n", cspc);
    fprintf(fpout, " */\n");
    fprintf(fpout,
-      "%sif (incX > 0 && incY > 0) goto L1;\n", spc);
+      "%sif (incX >= 0 && incY >= 0) goto L1;\n", spc);
    fprintf(fpout,
       "%selse if (incY < 0)\n", spc);
    fprintf(fpout,
